clear;
% clc;
% close all;

%% Options
run_optimisation = true;

%% Set up directories
current_dir = pwd;
Idx_backslash = find(current_dir == filesep);
main_dir = current_dir; %(1:Idx_backslash(end));
output_dir = [main_dir '\output' filesep];
storage_dir = current_dir; %[main_dir '\storage' filesep];

%% Define constants - coonsistent with VOLTS.
R = 8.314;
T = 310;
F = 96485;

%% Plot I-V curves
% UNITS:
%     I = G_GHK * K [=] mA
%     G_GHK = I/K [=] Amp.litre/mol
%     G_PMR [=] mS [=] mA/V
    
V = (-120:1:60)/1000;

cCao = 1.8;
cCai = 6e-5;
Cai = 6e-5; %millimolar
z = 2;
Cm = 0.001; % Unit microF

G_pmr = 0.003016*Cm; % g_Cab: milliS_per_microF {init: 0.003016}; 

E_Ca = R*T/(z*F)*log(cCao/cCai);
E_Ca_st = R*T/(z*F)*log(cCao/cCai);

I_lin = G_pmr*(V-E_Ca); % Unit mA    don't consider gating variable: just finding conductance.

Vstart = 1;
Vend = length(V);
error_func = @(G_GHK) square_error(I_lin(Vstart:Vend) - calc_IGHK(G_GHK,V(Vstart:Vend),cCai,cCao));

A = [];
b = [];
Aeq = [];
beq = [];
lb = [-Inf];
ub = [Inf];

options_ps = optimoptions('particleswarm','UseParallel',false,'HybridFcn',@fminunc,'SwarmSize',1000, ...
    'FunctionTolerance', 1e-9);

if run_optimisation
    [G_GHK,fval,exitflag,output] = particleswarm(error_func,1,lb,ub,options_ps);
    save([storage_dir '\cab_G_GHK.mat'],'G_GHK');
else
    load([storage_dir '\cab_G_GHK.mat']);
end

G_GHK2 = 0.00001;

I_GHK = calc_IGHK(G_GHK,V,cCai,cCao);
I_GHK2 = calc_IGHK(G_GHK2,V,cCai,cCao);

h = figure;
% subplot(1,2,1)
plot(1000*V,1e6*I_lin,'k--',1000*V,1e6*I_GHK);
legend('LRd','BG','Location','southeast');
ylabel('Current (nA)');
xlabel('Voltage (mV)');
set(gca,'FontSize',16);

% subplot(1,2,2)
% plot(1000*V,1e6*I_lin,'k--',1000*V, 1e6*I_GHK2);
% legend('LRd','BG_test','Location','southeast');
% ylabel('Current (nA)');
% xlabel('Voltage (mV)');
% set(gca,'FontSize',16);

% print_figure(h,output_dir,'tcc_IV_curve');