# fast Na module

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

# Translated from Pan 2018 cardiac AP 

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    # constants are stored in V
    F = V['F']
    N_A = V['N_A']

    x_Cab_channel = 725 / N_A * 1e15 #unit    fmol

    G_GHK = 1.2133039571743756E-7
    alpha = 10
    beta = 0

    # convert    to    permeability
    P_Cab = G_GHK / F * 1e12 #Unit    pL / s
    channel_k = P_Cab / x_Cab_channel

    kf =[channel_k]
    kr =[channel_k]
    k_kinetic = kf + kr

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo'], V['V_o']]

    return (k_kinetic, N_cT, K_C, W)













